coalib package
==============

Subpackages
-----------

.. toctree::

    coalib.bearlib
    coalib.bears
    coalib.collecting
    coalib.misc
    coalib.output
    coalib.parsing
    coalib.processes
    coalib.results
    coalib.settings
    coalib.testing

Submodules
----------

coalib.coala module
-------------------

.. automodule:: coalib.coala
    :members:
    :undoc-members:
    :show-inheritance:

coalib.coala_ci module
----------------------

.. automodule:: coalib.coala_ci
    :members:
    :undoc-members:
    :show-inheritance:

coalib.coala_delete_orig module
-------------------------------

.. automodule:: coalib.coala_delete_orig
    :members:
    :undoc-members:
    :show-inheritance:

coalib.coala_format module
--------------------------

.. automodule:: coalib.coala_format
    :members:
    :undoc-members:
    :show-inheritance:

coalib.coala_json module
------------------------

.. automodule:: coalib.coala_json
    :members:
    :undoc-members:
    :show-inheritance:

coalib.coala_main module
------------------------

.. automodule:: coalib.coala_main
    :members:
    :undoc-members:
    :show-inheritance:

coalib.coala_modes module
-------------------------

.. automodule:: coalib.coala_modes
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: coalib
    :members:
    :undoc-members:
    :show-inheritance:
